bayespy.inference.vmp.nodes.categorical.CategoricalDistribution.compute_fixed_moments_and_f
===========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. automethod:: CategoricalDistribution.compute_fixed_moments_and_f